﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.IO;
using ColorCode;
using SelectPdf;

namespace SelectPdf.Samples
{
    public partial class PdfWatermarks : Form
    {
        private void BtnCreatePdf_Click(object sender, EventArgs e)
        {
            Cursor = Cursors.WaitCursor;
            string file = "Document.pdf";

            try
            {
                // create a new pdf document
                PdfDocument doc = new PdfDocument();

                // create a new pdf font
                PdfFont font = doc.AddFont(PdfStandardFont.Helvetica);
                font.Size = 24;

                // add a new page to the document
                PdfPage page = doc.AddPage();

                // create a new text element and add it to the page
                PdfTextElement text = new PdfTextElement(0, 0, Helper.SomeLongText(), font);
                page.Add(text);

                // get image path
                string imgFile = AppDomain.CurrentDomain.BaseDirectory + "/../../files/logo.png";

                // watermark all pages - add a template containing an image 
                // to the bottom right of the page
                // the image should repeat on all pdf pages automatically
                // the template should be rendered behind the rest of the page elements
                PdfTemplate template = doc.AddTemplate(doc.Pages[0].ClientRectangle);
                PdfImageElement img = new PdfImageElement(
                    doc.Pages[0].ClientRectangle.Width - 300,
                    doc.Pages[0].ClientRectangle.Height - 150, imgFile);
                img.Transparency = 50;
                template.Background = true;
                template.Add(img);

                // save pdf document
                doc.Save(file);

                // close pdf document
                doc.Close();
            }
            catch (Exception ex)
            {
                MessageBox.Show(String.Format("Error: {0}", ex.Message),
                    "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
            finally
            {
                Cursor = Cursors.Arrow;
            }

            // open generated pdf
            try
            {
                System.Diagnostics.Process.Start(file);
            }
            catch
            {
                MessageBox.Show("Could not open generated pdf document",
                    "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        public PdfWatermarks()
        {
            InitializeComponent();

            try
            {
                // display highlighted sample code
                string code = File.ReadAllText(AppDomain.CurrentDomain.BaseDirectory +
                    "/../../" + "PdfWatermarks.cs");
                WBSampleCode.DocumentText = new CodeColorizer().Colorize(code, Languages.CSharp);
            }
            catch
            {
                WBSampleCode.DocumentText = "Sample code not available";
            }
        }

    }
}
